@@ -27,8 +27,6 @@ def train_test_split(cv, X, y, random_state=False, **kwargs):
 
     Parameters
     -----------
-        Parameters
-    ----------
     cv : cross-validation function.
         Allowed function from museotoolbox as scikit-learn.
     X : array-like, shape (n_samples, n_features), optional
@@ -48,9 +46,8 @@ def train_test_split(cv, X, y, random_state=False, **kwargs):
     import museotoolbox as mtb
 
     X, y = np.arange(10).reshape((5, 2)), range(5)
-    cv = mtb.cross_validation.LeaveOneOut
-    X_train, y_train, X_test, y_test = mtb.cross_validation.train_test_split(cv,X,y,random_state=42)
-
+    cv = mtb.cross_validation.LeaveOneOut(random_state=42)
+    X_train, y_train, X_test, y_test = mtb.cross_validation.train_test_split(cv,X,y)
     """
     # X_train, X_test = [np.asarray([],dtype=X.dtype).reshape(-1,X.shape[-1])]*2 # empty X
     # y_train, y_test = [np.asarray([],dtype=np.int64)]*2 # empty y
@@ -62,9 +59,18 @@ def train_test_split(cv, X, y, random_state=False, **kwargs):
         y_train = y[tr]
         X_test = X[vl, ...]
         y_test = y[vl]
-
+        if 'groups' in kwargs:
+            g = kwargs['groups']
+            if g.ndim == 2:
+                g = y.flatten()
+            g_train = g[tr, ...]
+            g_test = g[vl, ...]
         break  # only the first fold is needed
-    return X_train, X_test, y_train, y_test
+
+    if 'groups' in kwargs:
+        return X_train, X_test, y_train, y_test, g_train, g_test
+    else:
+        return X_train, X_test, y_train, y_test
 
 
 class LeaveOneOut(_sample_selection._cv_manager):
@@ -89,8 +95,12 @@ class LeaveOneOut(_sample_selection._cv_manager):
                  random_state=False,
                  verbose=False):
 
-        super().__init__(_sample_selection.randomPerClass, valid_size=1,
-                         n_repeats=n_repeats, random_state=random_state, verbose=verbose)
+        super().__init__(
+            _sample_selection.randomPerClass,
+            valid_size=1,
+            n_repeats=n_repeats,
+            random_state=random_state,
+            verbose=verbose)
 
 
 class LeavePSubGroupOut(_sample_selection._cv_manager):
@@ -123,11 +133,15 @@ class LeavePSubGroupOut(_sample_selection._cv_manager):
         else:
             raise ValueError(
                 'Percent must be between 0 and 1 and must be a float')
-        if n_repeats == False:
+        if not n_repeats:
             n_repeats = int(1 / valid_size)
 
-        super().__init__(_sample_selection.groupCV, valid_size=valid_size,
-                         n_repeats=n_repeats, random_state=random_state, verbose=verbose)
+        super().__init__(
+            _sample_selection.groupCV,
+            valid_size=valid_size,
+            n_repeats=n_repeats,
+            random_state=random_state,
+            verbose=verbose)
 
 
 class LeaveOneSubGroupOut(_sample_selection._cv_manager):
@@ -151,8 +165,12 @@ class LeaveOneSubGroupOut(_sample_selection._cv_manager):
                  random_state=False,
                  verbose=False):
 
-        super().__init__(_sample_selection.groupCV, valid_size=1, n_repeats=n_repeats,
-                         random_state=random_state, verbose=verbose)
+        super().__init__(
+            _sample_selection.groupCV,
+            valid_size=1,
+            n_repeats=n_repeats,
+            random_state=random_state,
+            verbose=verbose)
 
 
 class SpatialLeaveAsideOut(_sample_selection._cv_manager):
@@ -187,8 +205,13 @@ class SpatialLeaveAsideOut(_sample_selection._cv_manager):
                  random_state=False,
                  verbose=False):
 
-        super().__init__(_sample_selection.distanceCV, distance_matrix=distance_matrix,
-                         valid_size=valid_size, n_repeats=n_repeats, random_state=random_state, verbose=verbose)
+        super().__init__(
+            _sample_selection.distanceCV,
+            distance_matrix=distance_matrix,
+            valid_size=valid_size,
+            n_repeats=n_repeats,
+            random_state=random_state,
+            verbose=verbose)
 
 
 class SpatialLeaveOneSubGroupOut(_sample_selection._cv_manager):
@@ -221,10 +244,13 @@ class SpatialLeaveOneSubGroupOut(_sample_selection._cv_manager):
                  random_state=False,
                  verbose=False):
 
-        super().__init__(_sample_selection.distanceCV, distance_matrix=distance_matrix,
-                         distance_thresold=distance_thresold,
-                         distance_label=distance_label,
-                         random_state=random_state, verbose=verbose)
+        super().__init__(
+            _sample_selection.distanceCV,
+            distance_matrix=distance_matrix,
+            distance_thresold=distance_thresold,
+            distance_label=distance_label,
+            random_state=random_state,
+            verbose=verbose)
 
 
 class SpatialLeaveOneOut(_sample_selection._cv_manager):
@@ -266,15 +292,17 @@ class SpatialLeaveOneOut(_sample_selection._cv_manager):
                  verbose=False,
                  **kwargs):
 
-        super().__init__(_sample_selection.distanceCV, distance_matrix=distance_matrix,
-                         distance_thresold=distance_thresold,
-                         distance_label=False,
-                         valid_size=1,
-                         n_repeats=n_repeats,
-                         n_splits=n_splits,
-                         random_state=random_state,
-                         verbose=verbose,
-                         **kwargs)
+        super().__init__(
+            _sample_selection.distanceCV,
+            distance_matrix=distance_matrix,
+            distance_thresold=distance_thresold,
+            distance_label=False,
+            valid_size=1,
+            n_repeats=n_repeats,
+            n_splits=n_splits,
+            random_state=random_state,
+            verbose=verbose,
+            **kwargs)
 
 
 class RandomStratifiedKFold(_sample_selection._cv_manager):
@@ -322,6 +350,9 @@ class RandomStratifiedKFold(_sample_selection._cv_manager):
         else:
             n_repeats = n_splits * n_repeats
 
-        super().__init__(_sample_selection.randomPerClass, valid_size=valid_size,
-                         random_state=random_state,
-                         n_repeats=n_repeats, verbose=verbose)
+        super().__init__(
+            _sample_selection.randomPerClass,
+            valid_size=valid_size,
+            random_state=random_state,
+            n_repeats=n_repeats,
+            verbose=verbose)
